==========
Quickstart
==========

This section is for users that are already familiar with writing configuration files for WAMIT, HAMS or Nemoh and just want to do the same with Capytaine.
If you want to understand the internal structure of Capytaine to customize it to your need, see the :doc:`tutorial` instead.

You can use the following script as the equivalent configuration file for Capytaine.
Copy it in a Python file, edit it to suit your needs and execute it with Python to run the study.
More example files can be found in the :doc:`cookbook`.

.. literalinclude:: examples/quickstart.py
   :language: python


